@@ -5,8 +5,8 @@
 """
 
 # 版本信息
-__version__ = "1.0.0"
-__version_info__ = (1, 0, 0)
+__version__ = "1.0.1"
+__version_info__ = (1, 0, 1)
 
 # 项目信息
 __title__ = "CodeLens"
@@ -14,7 +14,7 @@ __description__ = "智能代码搜索引擎，支持语义搜索和代码分析"
 __author__ = "CodeLens Team"
 __author_email__ = "support@codelens.dev"
 __license__ = "MIT"
-__url__ = "https://github.com/your-org/CodeLens"
+__url__ = "https://github.com/sokis/CodeLens"
 
 # 构建信息
 __build__ = "stable"
