@@ -41,7 +41,7 @@ class CodeSearchWebApp:
         
         # 创建 Flask 应用
         self.app = Flask(__name__)
-        self.app.secret_key = 'your-secret-key-here'  # 在生产环境中应该使用环境变量
+        self.app.secret_key = os.environ.get('FLASK_SECRET_KEY', 'dev-key-only-not-for-production')  # 生产环境必须设置FLASK_SECRET_KEY环境变量
         
         # 注册路由
         self._register_routes()
